aboutsummaryrefslogtreecommitdiffhomepage
path: root/tests/PictureShaderTest.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tests/PictureShaderTest.cpp')
-rw-r--r--tests/PictureShaderTest.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tests/PictureShaderTest.cpp b/tests/PictureShaderTest.cpp
index 113f4f86ee..14bdcf2d81 100644
--- a/tests/PictureShaderTest.cpp
+++ b/tests/PictureShaderTest.cpp
@@ -11,7 +11,7 @@
#include "SkShader.h"
#include "Test.h"
// Test that attempting to create a picture shader with a NULL picture or
// empty picture returns a shader that draws nothing.
DEF_TEST(PictureShader_empty, reporter) {
SkPaint paint;
@@ -23,7 +23,7 @@ DEF_TEST(PictureShader_empty, reporter) {
canvas.clear(SK_ColorGREEN);
SkShader* shader = SkShader::CreatePictureShader(
- NULL, SkShader::kClamp_TileMode, SkShader::kClamp_TileMode, NULL, NULL);
+ nullptr, SkShader::kClamp_TileMode, SkShader::kClamp_TileMode, nullptr, nullptr);
paint.setShader(shader)->unref();
canvas.drawRect(SkRect::MakeWH(1,1), paint);
@@ -31,10 +31,10 @@ DEF_TEST(PictureShader_empty, reporter) {
SkPictureRecorder factory;
- factory.beginRecording(0, 0, NULL, 0);
+ factory.beginRecording(0, 0, nullptr, 0);
SkAutoTUnref<SkPicture> picture(factory.endRecording());
shader = SkShader::CreatePictureShader(
- picture.get(), SkShader::kClamp_TileMode, SkShader::kClamp_TileMode, NULL, NULL);
+ picture.get(), SkShader::kClamp_TileMode, SkShader::kClamp_TileMode, nullptr, nullptr);
paint.setShader(shader)->unref();
canvas.drawRect(SkRect::MakeWH(1,1), paint);
@@ -11,7 +11,7 @@
#include "SkShader.h"
#include "Test.h"
-// Test that attempting to create a picture shader with a NULL picture or
+// Test that attempting to create a picture shader with a nullptr picture or
// empty picture returns a shader that draws nothing.
DEF_TEST(PictureShader_empty, reporter) {